@@ -9,22 +9,22 @@ test_that('is_unknown', {
   )
   expect_false(
     is_unknown("unknown")
-  )  
+  )
   expect_false(
     is_unknown(7)
   )
   expect_equal(
     is_unknown(c(1:2, unknown(), NA)),
     c(FALSE, FALSE, TRUE, FALSE)
-  )  
+  )
 })
 
 test_that('has_unknown', {
   expect_true(
-    has_unknowns(mtry)
+    has_unknowns(mtry())
   )
   expect_equal(
-    has_unknowns(list(mtry, mixture)),
+    has_unknowns(list(mtry(), mixture())),
     c(TRUE, FALSE)
-  )  
+  )
 })
